# coding=utf-8
from earthdiagnostics.diagnostic import Diagnostic


class Rewrite(Diagnostic):
    """
    Rewrites files without doing any calculations.
    Can be useful to convert units or to correct wrong metadata

    :original author: Javier Vegas-Regidor<javier.vegas@bsc.es>

    :created: July 2016

    :param data_manager: data management object
    :type data_manager: DataManager
    :param startdate: startdate
    :type startdate: str
    :param member: member number
    :type member: int
    :param chunk: chunk's number
    :type chunk: int
    :param variable: variable's name
    :type variable: str
    :param domain: variable's domain
    :type domain: str
    """

    alias = 'rewrite'
    "Diagnostic alias for the configuration file"

    def __init__(self, data_manager, startdate, member, chunk, variable, domain):
        Diagnostic.__init__(self, data_manager)
        self.startdate = startdate
        self.member = member
        self.chunk = chunk
        self.variable = variable
        self.domain = domain

    def __str__(self):
        return 'Rewrites output Startdate: {0} Member: {1} Chunk: {2} ' \
               'Variable: {3}:{4}'.format(self.startdate, self.member, self.chunk, self.domain, self.variable)

    @classmethod
    def generate_jobs(cls, diags, options):
        """
            Creates a job for each chunk to compute the diagnostic

            :param diags: Diagnostics manager class
            :type diags: Diags
            :param options: variable, domain, frequency=day
            :type options: list[str]
            :return:
            """
        num_options = len(options) - 1
        if num_options < 2:
            raise Exception('You must specify the variable and domain to average monthly')
        if num_options > 2:
            raise Exception('You must specify 2 parameters for the rewrite diagnostic')
        variable = options[1]
        domain = options[2]
        job_list = list()
        for startdate, member, chunk in diags.exp_manager.get_chunk_list():
            job_list.append(Rewrite(diags.data_manager, startdate, member, chunk, variable, domain))
        return job_list

    def compute(self):
        """
        Runs the diagnostic
        """
        variable_file = self.data_manager.get_file(self.domain, self.variable, self.startdate, self.member, self.chunk)
        self.data_manager.send_file(variable_file, self.domain, self.variable, self.startdate, self.member, self.chunk)

