# coding=utf-8
from unittest import TestCase
from earthdiagnostics.constants import Basins, Basin
from earthdiagnostics.box import Box


class TestBasins(TestCase):

    def test_parse(self):
        self.assertEquals(Basins.Arctic, Basins.parse(Basins.Arctic))
        self.assertEquals(Basins.Arctic, Basins.parse('Arct'))
        self.assertEquals(Basins.Arctic, Basins.parse('Arctic_Ocean'))
        self.assertIsNone(Basins.parse('Basin not found'))


class TestBasin(TestCase):

    def setUp(self):
        self.basin = Basin('bas', 'Basin', Box())

    def test_shortname(self):
        self.assertEquals('bas', self.basin.shortname)

    def test_fullname(self):
        self.assertEquals('Basin', self.basin.fullname)

    def test__eq__(self):
        self.assertTrue(Basin('bas', 'Basin') == self.basin)
        self.assertFalse(Basin('bas', 'OtherBasin') == self.basin)
        self.assertFalse(Basin('otbas', 'Basin') == self.basin)
        self.assertFalse(Basin('otbas', 'OtherBasin') == self.basin)
