# coding=utf-8

from unittest import TestCase
from earthdiagnostics.experimentmanager import ExperimentManager


class TestExperimentManager(TestCase):
    def setUp(self):
        self.experiment_manager = ExperimentManager(['20000101', '20000201'], [0, 1], 5, 3, 3)

    def test_get_full_years(self):
        self.assertEquals([2000], self.experiment_manager.get_full_years('20000101'))
        self.assertEquals(list(), self.experiment_manager.get_full_years('20000201'))

    def test_get_member_str(self):
        self.assertEquals('fc000', self.experiment_manager.get_member_str(0))
        self.assertEquals('fc001', self.experiment_manager.get_member_str(1))

    def test_get_member_list(self):
        self.assertEquals([('20000101', 0), ('20000101', 1), ('20000201', 0), ('20000201', 1)],
                          self.experiment_manager.get_member_list())

    def test_get_year_chunks(self):
        self.assertEquals([1, 2, 3, 4], self.experiment_manager.get_year_chunks('20000101', 2000))
        self.assertEquals([4, 5], self.experiment_manager.get_year_chunks('20000201', 2001))
        self.assertEquals(list(), self.experiment_manager.get_year_chunks('20000201', 2003))

    def test_get_chunk_list(self):
        self.assertEquals([('20000101', 0, 1), ('20000101', 0, 2), ('20000101', 0, 3), ('20000101', 0, 4),
                           ('20000101', 0, 5),
                           ('20000101', 1, 1), ('20000101', 1, 2), ('20000101', 1, 3), ('20000101', 1, 4),
                           ('20000101', 1, 5),
                           ('20000201', 0, 1), ('20000201', 0, 2), ('20000201', 0, 3), ('20000201', 0, 4),
                           ('20000201', 0, 5),
                           ('20000201', 1, 1), ('20000201', 1, 2), ('20000201', 1, 3), ('20000201', 1, 4),
                           ('20000201', 1, 5)],
                          self.experiment_manager.get_chunk_list())
